"use strict";

var path = require('path');

module.exports = function (api, externalOptions) {
  var _externalOptions$targ, _externalOptions$envi, _externalOptions$debu, _externalOptions$reac;

  api.assertVersion(7);
  var options = {
    target: (_externalOptions$targ = externalOptions.target) !== null && _externalOptions$targ !== void 0 ? _externalOptions$targ : 'js',
    environments: (_externalOptions$envi = externalOptions.environments) !== null && _externalOptions$envi !== void 0 ? _externalOptions$envi : {
      node: 'current',
      browsers: [// See: npx browserslist 'defaults'
      // https://github.com/browserslist/browserslist/blob/49af84894d7eb8a043f2b063f62efed71bb9ca09/index.js#L517-L522
      'defaults']
    },
    debug: (_externalOptions$debu = externalOptions.debug) !== null && _externalOptions$debu !== void 0 ? _externalOptions$debu : false,
    reactRuntime: (_externalOptions$reac = externalOptions.reactRuntime) !== null && _externalOptions$reac !== void 0 ? _externalOptions$reac : 'automatic'
  };
  var presets = [];
  var plugins = [path.join(__dirname, 'dev-expression-check.js')];
  var parserPlugins = [// See: https://babeljs.io/docs/en/babel-parser#plugins
  'jsx', ['flow', {
    enums: true
  }], 'flowComments', 'throwExpressions' // https://github.com/tc39/proposal-throw-expressions
  ];
  var retainLines = false;
  var target = options.target;

  if (target === 'flow') {
    plugins = plugins.concat([path.join(__dirname, 'dev-declaration.js')]);
    retainLines = true;
  } else if (target === 'js' || target === 'js-esm') {
    var supportsESM = target === 'js-esm';
    presets = presets.concat([['@babel/preset-env', {
      debug: options.debug,
      modules: supportsESM ? false : 'commonjs',
      targets: options.environments,
      bugfixes: true
    }], ['@babel/preset-react', {
      runtime: options.reactRuntime
    }]]);
    plugins = plugins.concat([path.join(__dirname, 'dev-expression.js'), path.join(__dirname, 'adeira-js-invariant.js'), path.join(__dirname, 'adeira-js-warning.js'), 'babel-plugin-transform-flow-enums', ['@babel/plugin-transform-flow-strip-types', {
      // See: https://babeljs.io/docs/en/babel-plugin-transform-flow-strip-types#allowdeclarefields
      // See: https://github.com/babel/babel/pull/11178
      // See: https://github.com/facebook/flow/commit/11b7adbf85ea237cfc01d1b8dc6f6dcdbc299157
      allowDeclareFields: true
    }], '@babel/plugin-proposal-throw-expressions', // Transform runtime plugin turns common chunks of code into imports. However, this
    // requires `@babel/runtime` dependency thus we are requiring it as well.
    // See: https://babeljs.io/docs/en/babel-plugin-transform-runtime
    ['@babel/plugin-transform-runtime', {
      useESModules: supportsESM
    }]]);
  } else {
    target;
    throw new Error('options.target must be one of "js", "js-esm" or "flow".');
  }

  return {
    presets: presets,
    plugins: plugins,
    parserOpts: {
      plugins: parserPlugins
    },
    retainLines: retainLines // TODO: sourceType: 'unambiguous',

  };
};